<?php

if (!defined('_PS_VERSION_')) {
    die('!_PS_VERSION_');
}

class RtnetSubsync extends Module
{

    public static $_version = '2.1';

    public function __construct()
    {
        $this->name = 'RtnetSubSync';
        $this->tab = 'administration';
        $this->version = self::$_version;
        $this->author = 'rtnet.pl';
        $this->need_instance = 0;
        $this->is_configurable = 1;
        $this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_);
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('RTNET SubSync (Integratory.pl)');
        $this->description = $this->l('Integracja PrestaShop i Subiekt GT/Subiekt NEXO PRO/Navireo/WAPRO Mag/Symfonia');

        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');
    }

    public function install()
    {
        $db = Db::getInstance();
        if (!function_exists('ioncube_loader_version')) {
            $this->_errors[] = 'Nie znaleziono IonCube Loader. Włącz IonCube w konfiguracji Twojego serwera.';
            return false;
        }

        // require_once __DIR__ . '/Broker/Broker.php';
        // $broker = new RTNET\Broker(false);
        return parent::install() && $this->registerHook('displayPDFInvoice') && $this->enable();
    }

    public function enable($force_all = false)
    {
        if (!function_exists('ioncube_loader_version')) {
            $this->_errors[] = 'Nie znaleziono IonCube Loader. Włącz IonCube w konfiguracji Twojego serwera.';
            return false;
        }
        return parent::enable();
    }

    public function hookDisplayPDFInvoice($params)
    {
        try {
            require_once __DIR__ . '/Broker/Broker.php';
            require_once RTNET\Rtnetss_Broker_MakeScriptName('/Store.php');
            $pdfdir = RTNET\Store::PreparePdfDir();
            $id_order = (int) $params['object']->id_order;

            if (!$id_order) {
                throw new Exception('Missing parameter: id_order');
            }

            $is_admin = (int) Context::getContext()->cookie->id_employee > 0;

            if (!$is_admin) {
                $id_customer = (int) Context::getContext()->cookie->id_customer;
                if (!$id_customer) {
                    throw new Exception('Missing parameter: id_customer');
                }
            }

            if ($is_admin) {
                $query = "SELECT i.*, eo.`notes1`, i.`document_number` FROM `zzz_RtnetInvoices` i"
                . " LEFT JOIN `zzz_RtnetExportedOrders` eo ON eo.`order_id` = i.`id_order`"
                . " WHERE `id_order` = '" . (int) $id_order . "';";
            } else {
                $query = "SELECT i.*, eo.`notes1`, i.`document_number` FROM `zzz_RtnetInvoices` i"
                . " INNER JOIN `" . _DB_PREFIX_ . "orders` o ON o.`id_customer` = '" . (int) $id_customer . "' AND o.`id_order` = i.`id_order`"
                . " LEFT JOIN `zzz_RtnetExportedOrders` eo ON eo.`order_id` = i.`id_order`"
                . " WHERE i.`id_order` = '" . (int) $id_order . "';";
            }

            $db = Db::getInstance();
            $result = $db->executeS($query);

            if (!$result || count($result) < 1) {
                // throw new Exception('Invoice not found');
                return true; // spróbuj wyświetlić istniejący dokument "starym" trybem
            }

            if (!$result[0]['file']) {
                throw new Exception('Invoice file empty');
            }

            $fn = $pdfdir . '/' . $result[0]['file'];

            if (!file_exists($fn)) {
                throw new Exception('Invoice file not found: ');
            }

            $att_name = "Invoice-' . (int) $id_order . '.pdf";
            if ($result[0]['notes1']) {
                $att_name = preg_replace('/[^A-Za-z0-9_\-]/', '_', $result[0]['notes1']) . '.pdf';
            }
            if ($result[0]['document_number']) {
                $att_name = preg_replace('/[^A-Za-z0-9_\-]/', '_', $result[0]['document_number']) . '.pdf';
            }
            header('Content-Type: application/pdf');
            header('Content-Disposition: attachment; filename="' . $att_name . '"');
            readfile($fn);
            die;
        } catch (Exception $e) {
            // die($e->getMessage());
            Tools::redirect('index.php?controller=404');
            die;
        }

        return true;
    }

    public function uninstall()
    {
        return parent::uninstall();
    }

    public function getContent()
    {
        return $this->displayForm();
    }

    public function displayForm()
    {
        require_once __DIR__ . '/Broker/Broker.php';
        $broker = new RTNET\Broker(false);
        $moduleform_url = 'index.php?controller=AdminModules&configure=RtnetSubSync&module_name=RtnetSubSync&token=' . Tools::getAdminTokenLite('AdminModules');
        $reset_url = $moduleform_url . '&resetSecrets=1';

        if (isset($_GET['resetSecrets']) && $_GET['resetSecrets'] == '1') {
            $broker->CreateSecrets();
            if (!headers_sent()) {
                header('Location: ' . $moduleform_url);
                die;
            }
        }

        $secrets = $broker->GetSecrets();

        $fields_form[0]['form'] = array();

        $helper = new HelperForm();

        $helper->module = $this;
        $helper->name_controller = $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex . '&configure=' . $this->name;

        $helper->default_form_language = $default_lang;
        $helper->allow_employee_form_lang = $default_lang;

        $helper->title = $this->displayName;
        $helper->show_toolbar = true;
        $helper->toolbar_scroll = true;
        $helper->submit_action = 'submit' . $this->name;

        $helper->toolbar_btn = array(
            'back' => array(
                'href' => AdminController::$currentIndex . '&token=' . Tools::getAdminTokenLite('AdminModules'),
                'desc' => $this->l('Back to list'),
            ),
        );

        $broker_address = '/RtnetSubSync/Broker/Broker.php';

        $runUrl = 'http' . (isset($_SERVER['HTTPS']) ? 's' : '') . '://' . $_SERVER['HTTP_HOST'] . '/' . trim(__PS_BASE_URI__, '/') . '/modules/' . $this->name . '/Broker/Broker.php';

        $html = '
		<div class="panel">
			<div class="panel-heading">
				RTNET SubSync - Integracja PrestaShop i Subiekt GT/NEXO PRO
			</div>
			<div class="form-wrapper">
				<p>Adres brokera:<br /><input type="text" readonly value="' . $runUrl . '" /></p>
				<p>Klucz Secret:<br /><input type="text" readonly value="' . $secrets['secret'] . '" /></p>
				<p><a href="#" onclick="rtCopyToClipboard(); return false;">Kopiuj do schowka</a> <input type="text" id="__fc" value="' . base64_encode('[[' . $runUrl . '|' . $secrets['secret'] . ']]') . '" style="display: none !important;" /></p>
				<p><a href="' . htmlspecialchars($reset_url) . '" onclick="return confirm(\'Czy na pewno zresetować klucz? Po tej operacji będzie wymagana aktualizacja konfiguracji integratora\');">Kliknij tutaj, aby zresetować secret</a></p>
			</div>
		</div>';
        $html .= "
		<script>
		function rtCopyToClipboard() {
			var node = document.getElementById('__fc');
			node.style = '';
			node.focus();
			node.select();
			document.execCommand('copy');
			node.style = 'display: none !important;';
		}
		</script>
		";

        return $helper->generateForm($fields_form) . $html;
    }
}
